==> powerprefs_0.4.9.orig.tar.gz: powerprefs-0.4.9/src/taghandler.h <==
#ifndef INCLUDE_TAGHANDLER_H
#define INCLUDE_TAGHANDLER_H
/* ----------------------------------------------------------------------------
 * taghandler.h
 * prototypes and definitions for taghandler.c.
 *
 * Copyright 2002 Matthias Grimm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 * ----------------------------------------------------------------------------*/

#define THMODE_GET	0
#define THMODE_SET	1

#define MOD_NONE			0
#define MOD_SHIFT			1     /* 001 */
#define MOD_ALT				2     /* 010 */
#define MOD_CTRL			4     /* 100 */

/* prototypes */
long th_showtext (int mode, long tag, GtkWidget *widget, long data);
long th_showvalue (int mode, long tag, GtkWidget *widget, long data);
long th_textentry (int mode, long tag, GtkWidget *widget, long data);
long th_checkbox (int mode, long tag, GtkWidget *widget, long data);
long th_radiobutton (int mode, long tag, GtkWidget *widget, long data);
long th_keyentry (int mode, long tag, GtkWidget *widget, long data);
long th_modentry (int mode, long tag, GtkWidget *widget, long data);
long th_spinbutton (int mode, long tag, GtkWidget *widget, long data);
long th_combobox (int mode, long tag, GtkWidget *widget, long data);
long th_profile (int mode, long tag, GtkWidget *widget, long data);
long th_dummy (int mode, long tag, GtkWidget *widget, long data);
long th_soundsystem (int mode, long tag, GtkWidget *widget, long data);
long th_system (int mode, long tag, GtkWidget *widget, long data);

void update_profile_gui();
void get_key_and_modifier(char *arg, int *key, int *mod);
char* code_key_and_modifier (int key, int mod);

#endif    /* INCLUDE_TAGHANDLER_H */

==> powerprefs-0.8.0.tar.gz: powerprefs-0.8.0/src/taghandler.h <==
#ifndef INCLUDE_TAGHANDLER_H
#define INCLUDE_TAGHANDLER_H
/* ----------------------------------------------------------------------------
 * taghandler.h
 * prototypes and definitions for taghandler.c.
 *
 * Copyright 2002 Matthias Grimm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 * ----------------------------------------------------------------------------*/

#define THMODE_GET	0
#define THMODE_SET	1

#define MOD_NONE			0
#define MOD_SHIFT			1     /* 001 */
#define MOD_ALT				2     /* 010 */
#define MOD_CTRL			4     /* 100 */

/* prototypes */
long th_showtext (int mode, long tag, GtkWidget *widget, long data);
long th_showvalue (int mode, long tag, GtkWidget *widget, long data);
long th_showpvalue (int mode, long tag, GtkWidget *widget, long data);
long th_textentry (int mode, long tag, GtkWidget *widget, long data);
long th_checkbox (int mode, long tag, GtkWidget *widget, long data);
long th_radiobutton (int mode, long tag, GtkWidget *widget, long data);
long th_keyentry (int mode, long tag, GtkWidget *widget, long data);
long th_modentry (int mode, long tag, GtkWidget *widget, long data);
long th_spinbutton (int mode, long tag, GtkWidget *widget, long data);
long th_combobox (int mode, long tag, GtkWidget *widget, long data);
long th_profile (int mode, long tag, GtkWidget *widget, long data);
long th_dummy (int mode, long tag, GtkWidget *widget, long data);
long th_system (int mode, long tag, GtkWidget *widget, long data);
long th_autoadjparm (int mode, long tag, GtkWidget *widget, long data);
long th_autoadjmode (int mode, long tag, GtkWidget *widget, long data);

void update_profile_gui();
void get_key_and_modifier(char *arg, int *key, int *mod);
char* code_key_and_modifier (int key, int mod);

#endif    /* INCLUDE_TAGHANDLER_H */
